:tocdepth: 3

###################
SkyPy Documentation
###################

This package contains methods for modelling the Universe, galaxies and the
Milky Way. SkyPy simulates populations of astronomical objects, generating
random realisations of intrinsic and observed properties, with the
intention the simulations can then be compared to data as part of an inference
pipeline.

.. Important:: If you use SkyPy for work presented in a publication or talk
   please follow our :doc:`project/citation`.



.. _getting-started:

***************
Getting Started
***************

.. toctree::
   :maxdepth: 1

   install
   feature_list
   configuration_files
   examples/index

.. _user-docs:

******************
User Documentation
******************

Packages
--------

.. toctree::
   :maxdepth: 1

   galaxies
   utils/index

Pipeline
--------

.. toctree::
   :maxdepth: 1

   pipeline/index


.. _developer-docs:

***********************
Developer Documentation
***********************

.. toctree::
   :maxdepth: 1

   developer/contributing


.. _project-details:

***************
Project details
***************

.. toctree::
   :maxdepth: 1

   project/code_of_conduct
   project/citation


*****
Index
*****

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

****************
Acknowledgements
****************

Logo Credit: `Maria Fonseca de la Bella <https://www.linkedin.com/in/mariadelabella>`_
